package com.youngho;

import java.util.ArrayList;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Paint.Align;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;

public class Itab extends View {

	private Paint 					mPaint;
	private Paint 					mActiveTextPaint;
	private Paint 					mInactiveTextPaint;
	private ArrayList<TabMember> 	mTabMembers;
	private int 					mActiveTab;
	private OnTabClickListener		mOnTabClickListener = null;
	
	
	public Itab(Context context, AttributeSet attrs) {
		super(context, attrs);
		
		mTabMembers = new ArrayList<TabMember>();
		
		mPaint = new Paint();
		mActiveTextPaint = new Paint();
		mInactiveTextPaint = new Paint();
		
		mPaint.setStyle(Paint.Style.FILL);
		mPaint.setColor(0xFFFFFF00);
		mPaint.setAntiAlias(true);
		
		mActiveTextPaint.setTextAlign(Align.CENTER);
		mActiveTextPaint.setTextSize(12);
		mActiveTextPaint.setColor(0xFFFFFFFF);
		mActiveTextPaint.setAntiAlias(true);
		
		mInactiveTextPaint.setTextAlign(Align.CENTER);
		mInactiveTextPaint.setTextSize(12);
		mInactiveTextPaint.setColor(0xFF999999);
		mInactiveTextPaint.setAntiAlias(true);
		
		mActiveTab = 0;		
	}

	@Override
	protected void onDraw(Canvas canvas) {
		// TODO Auto-generated method stub
		super.onDraw(canvas);
		
		Rect r = new Rect();
		this.getDrawingRect(r);
		
		int singleTabWidth = r.right/(mTabMembers.size() != 0 ? mTabMembers.size() : 1);
		
		canvas.drawColor(0xFF000000);
		mPaint.setColor(0xFF434343);
		canvas.drawLine(r.left, r.top+1, r.right, r.top+1, mPaint);
		
		int color=46;
		for(int i=0; i<24; i++){
			mPaint.setARGB(255, color, color, color);
			canvas.drawRect(r.left, r.top+i+1, r.right,r.top+i+2,mPaint);
			color--;
		}
		
		for(int i=0; i<mTabMembers.size(); i++){
			TabMember tabMember = mTabMembers.get(i);
			
			Bitmap icon = BitmapFactory.decodeResource(getResources(), tabMember.getmIconResourceId());
			Bitmap iconColored = Bitmap.createBitmap(icon.getWidth(),icon.getHeight(),Bitmap.Config.ARGB_8888);
			Paint p = new Paint(Paint.ANTI_ALIAS_FLAG | Paint.FILTER_BITMAP_FLAG);
			Canvas iconCanvas = new Canvas();
			iconCanvas.setBitmap(iconColored);
			
			if(mActiveTab == i){
				p.setShader(new LinearGradient(0, 0, icon.getWidth(), icon.getHeight(), 
						0xFFFFFFFF, 0xFF54C7E1, Shader.TileMode.CLAMP));
			}
			else{
				p.setShader(new LinearGradient(0, 0, icon.getWidth(), icon.getHeight(), 
						0xFFA2A2A2, 0xFF5F5F5F, Shader.TileMode.CLAMP));
			}
			
			iconCanvas.drawRect(0, 0, icon.getWidth(), icon.getHeight(), p);
			
			for(int x=0; x<icon.getWidth(); x++){
				for(int y=0; y<icon.getHeight(); y++){
					if((icon.getPixel(x, y) & 0xFF000000) == 0){
						iconColored.setPixel(x, y, 0x000000);
					}
				}
			}
			
			int tabImgX = singleTabWidth * i + (singleTabWidth / 2 - icon.getWidth() / 2);
			
			if(mActiveTab == i){
				mPaint.setARGB(37, 255, 255, 255);
				canvas.drawRoundRect(new RectF(r.left + singleTabWidth * i + 3, r.top + 3,
						r.left + singleTabWidth * (i+1) - 3,r.bottom-2), 5, 5, mPaint);
				canvas.drawBitmap(iconColored, tabImgX, r.top + 5, null);
				canvas.drawText(tabMember.getmText(), 
						singleTabWidth*i + (singleTabWidth/2), r.bottom-2, mActiveTextPaint);
			}
			else{
				canvas.drawBitmap(iconColored, tabImgX, r.top + 5, null);
				canvas.drawText(tabMember.getmText(), 
						singleTabWidth*i + (singleTabWidth/2), r.bottom-2, mInactiveTextPaint);
			}
		}
	}
	
	
	
	@Override
	public boolean onTouchEvent(MotionEvent event) {
		// TODO Auto-generated method stub
		Rect r = new Rect();
		this.getDrawingRect(r);
		float singleTabWidth = r.right/(mTabMembers.size() != 0 ? mTabMembers.size() : 1);
		
		int pressedTab = (int)((event.getX()/singleTabWidth) - (event.getX()/singleTabWidth) % 1);
		
		mActiveTab = pressedTab;
		
		if(this.mOnTabClickListener != null){
			this.mOnTabClickListener.onTabClick(mTabMembers.get(pressedTab).getmId());
		}
		this.invalidate();
		
		return super.onTouchEvent(event);
	}

	void addTabMember(TabMember tabMember){
		mTabMembers.add(tabMember);
	}
	
	void setOnTabClickListener(OnTabClickListener onTabClickListener){
		mOnTabClickListener = onTabClickListener;
	}

	//TabMember
	public static class TabMember{
		protected int 		mId;
		protected String 	mText;
		protected int 		mIconResourceId;
		
		public TabMember(int id, String text, int iconResourceId) {
			// TODO Auto-generated constructor stub
			this.mId = id;
			this.mText = text;
			this.mIconResourceId = iconResourceId;
		}

		public int getmId() {
			return mId;
		}

		public void setmId(int mId) {
			this.mId = mId;
		}

		public String getmText() {
			return mText;
		}

		public void setmText(String mText) {
			this.mText = mText;
		}

		public int getmIconResourceId() {
			return mIconResourceId;
		}

		public void setmIconResourceId(int mIconResourceId) {
			this.mIconResourceId = mIconResourceId;
		}
	}
	
	public static interface OnTabClickListener{
		public abstract void onTabClick(int tabId);
	}
}
